@@ -8,11 +8,14 @@ def sql(key):
     switcher = {
         'UserID':{'sql':'select userId from User where loginName = "admin";','database':'AnyRobot'},
         'MLID': {'sql': "select id from MLJob ;", 'database': 'AnyRobotML'},
-        'entityID': {'sql': "select id from Entity;", 'database': 'AnyRobot'},
-        'groupID': {'sql': "select id from EntityGroup;", 'database': 'AnyRobot'},
+        'entityID': {'sql': "select id from KAIEntity;", 'database': 'AnyRobot'},
+        'groupID': {'sql': "select id from KAIEntityGroup;", 'database': 'AnyRobot'},
         'AlertRuleID': {'sql': "select id from RuleEngineAlert;", 'database': 'AnyRobot'},
-        'kpiID': {'sql': "select id from DBIOKpi;", 'database': 'AnyRobot'},
-        'AddEntityID': {'sql': "select entityId from ConditionKey where conditionValues = '192.168.84.26' AND conditionKeys = 'host';",'database': 'AnyRobot'}
+        'kpiID': {'sql': "select id from KAIKpi;", 'database': 'AnyRobot'},
+        'AddEntityID': {'sql': "select entityId from KAIEntityCondition where conditionValues = '192.168.84.26' AND conditionKeys = 'host';",'database': 'AnyRobot'},
+        'KpiTemplateID': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
+        'KpiTemplateID1': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
+        'KpiTemplateID2': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'}
     }
 
     if switcher.get(key) is not None:
