@@ -72,6 +72,9 @@ class ParaDateFiledServer(object):
     def getEndTime(self):
         return int(round(time.time() * 1000))
 
+    def getUpdateTime(self):
+        return int(round(time.time()))
+
     def getEtlPortIll(self):
         portList = [port for port in range(10000, 20000)]
         port = random.choice(portList)
